% ComputeRealStable.m -- uses Bertini to compute the real stable solutions
% Copyright 2016
% Jonathan Hauenstein

function [numReal,Real,isPositive,isStable] = ComputeRealStable(g12,g23,g34)
% given parameters g12,g23,g34, compute the real and stable solutions
numReal = 0; Real = []; isStable = [];

% solve the system
cd Solve/
CreateStart([g12;g23;g34],3,1,'final_parameters');
eval('!bertini input_param start_81 > /dev/null');
[nP,P] = ReadInStart(4,'finite_solutions');
if nP ~= 81
  disp('Error in computing the solutions!');
  return;
end;

% find the real solutions
isReal = zeros(1,nP);
for k = 1:nP
  if norm(imag(P(k,:))) < 1e-8
    % P(k,:) is real
    P(k,:) = real(P(k,:));
    isReal(k) = 1;
  end;
end;    
Real = P(isReal == 1,:);
numReal = size(Real,1);

% find positive and stable ones
isPositive = zeros(1,numReal);
isStable = zeros(1,numReal);
for k = 1:numReal
  if min(Real(k,:)) > 0
    isPositive(k) = 1;
    M = evalJac(Real(k,:),g12,g23,g34);
    if max(eig(M)) < 1e-8
      % stable
      isStable(k) = 1;
    end;
  end;
end;
cd ../

return;

function [J] = evalJac(x,g12,g23,g34)

a = 0.4;
eps = 0.01;

J = zeros(4,4);

J(1,1) = -3*x(1)^2+2*(1+a+eps)*x(1)-a*eps-a-eps-g12;
J(1,2) = g12;
J(2,1) = g12;
J(2,2) = -3*x(2)^2+2*x(2)*(1+a+eps)-a*eps-a-eps-g23-g12;
J(2,3) = g23;
J(3,2) = g23;
J(3,3) = -3*x(3)^2+2*x(3)*(1+a+eps)-a*eps-a-eps-g34-g23;
J(3,4) = g34;
J(4,3) = g34;
J(4,4) = -3*x(4)^2+2*x(4)*(1+a+eps)-a*eps-a-eps-g34;

return;


