% PlotIntervals.m -- creates the movie frame from the interval files for a given g12
% Copyright 2016
% Jonathan Hauenstein

function [] = PlotIntervals(Vals)
% Vals = fixed value for g12

% setup colormap
T = colormap(vga);
X = [1 10 2 11 3 12 4 13 5 14 6 15 7 16 8];
T = T(X,:);
colormap(T);

    % setup based on fixing g23
    F = fopen(['SetupIntervals23/intervals_',num2str(Vals)],'r');
    c = 1;
    IntValues = zeros(1000,5);
    while ~feof(F)
      A = transpose(fscanf(F,'%e',5));
      if length(A) == 5
          IntValues(c,:) = A;
          c = c+1;
      else
          break;
      end;
    end;
    IntValues = IntValues(1:(c-1),:);
    fclose(F);

    % find the number of intervals per value of g23
    G23 = unique(IntValues(:,2));
    numG23 = zeros(1,length(G23));
    for j = 1:length(G23)
        numG23(j) = sum(IntValues(:,2) == G23(j));
    end;

    LeftPt = zeros(length(G23),max(numG23));
    RightPt = zeros(length(G23),max(numG23));
    NumSoln = zeros(length(G23),max(numG23));

    c = 1;
    for j = 1:length(G23)
        for k = 1:numG23(j)
          LeftPt(j,k) = IntValues(c,3);
          RightPt(j,k) = IntValues(c,4);
          NumSoln(j,k) = IntValues(c,5);
          c = c+1;
        end;
    end;

    % setup based on fixing g34
    F = fopen(['SetupIntervals34/intervals_34_',num2str(Vals)],'r');
    c = 1;
    IntValues34 = zeros(1000,5);
    while ~feof(F)
      A = transpose(fscanf(F,'%e',5));
      if length(A) == 5
          IntValues34(c,:) = A;
          c = c+1;
      else
          break;
      end;
    end;
    IntValues34 = IntValues34(1:(c-1),:);
    fclose(F);

    % find the number of intervals per value of g34
    G34 = unique(IntValues34(:,2));
    numG34 = zeros(1,length(G34));
    for j = 1:length(G34)
        numG34(j) = sum(IntValues34(:,2) == G34(j));
    end;

    LeftPt34 = zeros(length(G34),max(numG34));
    RightPt34 = zeros(length(G34),max(numG34));
    NumSoln34 = zeros(length(G34),max(numG34));

    c = 1;
    for j = 1:length(G34)
        for k = 1:numG34(j)
          LeftPt34(j,k) = IntValues34(c,3);
          RightPt34(j,k) = IntValues34(c,4);
          NumSoln34(j,k) = IntValues34(c,5);
          c = c+1;
        end;
    end;

    % plot based on both g23 & g34
    for j = 1:length(G23)
        for k = 1:numG23(j)
          plot([G23(j) G23(j)],[LeftPt(j,k) RightPt(j,k)],'Color',T(NumSoln(j,k)-1,:),'LineWidth',4); 
          hold on;
        end;
    end;

    for j = 1:length(G34)
        for k = 1:numG34(j)
          plot([LeftPt34(j,k) RightPt34(j,k)],[G34(j) G34(j)],'Color',T(NumSoln34(j,k)-1,:),'LineWidth',4); 
        end;
    end;

    % plot boundary points
    for j = 1:length(G23)
        for k = 1:numG23(j)
            plot([G23(j) G23(j)],[LeftPt(j,k) LeftPt(j,k)],'ks','MarkerSize',6,'MarkerFaceColor','k'); 
            plot([G23(j) G23(j)],[RightPt(j,k) RightPt(j,k)],'ks','MarkerSize',6,'MarkerFaceColor','k'); 
        end;
    end;

    % plot boundary points
    for j = 1:length(G34)
        for k = 1:numG34(j)
            plot([LeftPt34(j,k) LeftPt34(j,k)],[G34(j) G34(j)],'ks','MarkerSize',6,'MarkerFaceColor','k'); 
            plot([RightPt34(j,k) RightPt34(j,k)],[G34(j) G34(j)],'ks','MarkerSize',6,'MarkerFaceColor','k'); 
        end;
    end;

% setup the rest of the plot
hold off;
axis([0 0.1 0 0.1]);
axis square;
AX = gca;
AX.XTick = 0:0.02:0.1;
AX.YTick = 0:0.02:0.1;
c = colorbar('Ticks',(0.5:14.5)/15,'TickLabels',{'2','3','4','5','6','7','8','9','10','11','12','13','14','15','16'});
c.Label.String = 'Number of stable steady-state solutions';
xlabel('g_{2,3}');
ylabel('g_{3,4}');
S = num2str(Vals,10);
Z = '0000000';
if Vals == 0
    S = ['0.00000'];
elseif length(S) < 7
    S = [S,Z(1:7-length(S))];
end;
title(['g_{1,2} = ',S]);

return;


